@@ -680,7 +680,8 @@ PMOD_EXPORT struct array *array_remove(struct array *v,INT32 index)
   }
 }
 
-static ptrdiff_t fast_array_search( struct array *v, struct svalue *s, ptrdiff_t start )
+static ptrdiff_t fast_array_search( struct array *v, const struct svalue *s,
+                                    ptrdiff_t start )
 {
   ptrdiff_t e;
   struct svalue *ip = ITEM(v);
@@ -697,7 +698,7 @@ static ptrdiff_t fast_array_search( struct array *v, struct svalue *s, ptrdiff_t
  * @param start the index to start search at
  * @return the index if found, -1 otherwise
  */
-PMOD_EXPORT ptrdiff_t array_search(struct array *v, struct svalue *s,
+PMOD_EXPORT ptrdiff_t array_search(struct array *v, const struct svalue *s,
 				   ptrdiff_t start)
 {
 #ifdef PIKE_DEBUG
@@ -707,7 +708,7 @@ PMOD_EXPORT ptrdiff_t array_search(struct array *v, struct svalue *s,
 #ifdef PIKE_DEBUG
   if(d_flag > 1)  array_check_type_field(v);
 #endif
-  check_destructed(s);
+  safe_check_destructed(s);
 
   /* Why search for something that is not there?
    * however, we must explicitly check for searches
@@ -2109,7 +2110,7 @@ node *make_node_from_array(struct array *a)
   {
     debug_malloc_touch(a);
     for(e=0; e<a->size; e++)
-      if(ITEM(a)[e].u.integer != 0)
+      if(ITEM(a)[e].u.integer || SUBTYPEOF(ITEM(a)[e]))
 	break;
     if(e == a->size)
     {
@@ -2125,9 +2126,11 @@ node *make_node_from_array(struct array *a)
     {
       case BIT_INT:
 	for(e=1; e<a->size; e++)
-	  if(ITEM(a)[e].u.integer != ITEM(a)[0].u.integer)
+	  if((ITEM(a)[e].u.integer != ITEM(a)[0].u.integer) ||
+	     (SUBTYPEOF(ITEM(a)[e]) != SUBTYPEOF(ITEM(a)[0]))) {
 	    break;
-	if(e==a->size && ITEM(a)[0].u.integer==0)
+	  }
+	if(e==a->size && ITEM(a)[0].u.integer==0 && !SUBTYPEOF(ITEM(a)[0]))
 	  return mkefuncallnode("allocate",mkintnode(a->size));
 	break;
 	
