@@ -2,7 +2,6 @@
 || This file is part of Pike. For copyright information see COPYRIGHT.
 || Pike is distributed under GPL, LGPL and MPL. See the file COPYING
 || for more information.
-|| $Id: 2f82a7ec716492b935df960923ec65f29cd66577 $
 */
 
 #ifndef CALLBACK_H
@@ -22,10 +21,7 @@ extern struct callback_list fork_child_callback;
 
 typedef void (*callback_func)(struct callback *, void *,void *);
 
-#include "block_alloc_h.h"
 /* Prototypes begin here */
-struct callback;
-BLOCK_ALLOC(callback, CALLBACK_CHUNK);
 PMOD_EXPORT void low_call_callback(struct callback_list *lst, void *arg);
 PMOD_EXPORT struct callback *debug_add_to_callback(struct callback_list *lst,
 						   callback_func call,
@@ -34,6 +30,7 @@ PMOD_EXPORT struct callback *debug_add_to_callback(struct callback_list *lst,
 PMOD_EXPORT void *remove_callback(struct callback *l);
 void free_callback_list(struct callback_list *lst);
 void cleanup_callbacks(void);
+void count_memory_in_callbacks(size_t * num, size_t * size);
 /* Prototypes end here */
 
 #define add_to_callback(LST,CALL,ARG,FF) \
