@@ -413,9 +413,22 @@ static void maybe_update_pc(void)
   }
 }
 
+#ifdef OPCODE_INLINE_RETURN
+void ppc32_ins_entry(void)
+{
+  /* stwu r1, -32(r1) */
+  STWU(1, 1, -32);
+  /* mflr r0 */
+  MFSPR(0, PPC_SPREG_LR);
+  /* stw r0, 36(r1) */
+  STW(0, 1, 36);
+}
+#endif /* OPCODE_INLINE_RETURN */
+
 void ins_f_byte(unsigned int b)
 {
   void *addr;
+  INT32 rel_addr;
 
   b-=F_OFFSET;
 #ifdef PIKE_DEBUG
@@ -465,10 +478,54 @@ void ins_f_byte(unsigned int b)
   case F_ESCAPE_CATCH - F_OFFSET:
     ppc32_escape_catch();
     return;
+
+#ifdef OPCODE_INLINE_RETURN
+  case F_CATCH - F_OFFSET:
+    /* Special argument for the F_CATCH instruction. */
+    addr = inter_return_opcode_F_CATCH;
+    /* bl .+4 */
+    BL(4);
+    /* mflr r3 */
+    MFSPR(PPC_REG_ARG1, PPC_SPREG_LR);
+    rel_addr = PIKE_PC;
+    /* addi r3, r3, offs */
+    ADDI(PPC_REG_ARG1, PPC_REG_ARG1, 4);
+    break;
+#endif
   }
 
   FLUSH_CODE_GENERATOR_STATE();
   ADD_CALL(addr);
+#ifdef OPCODE_INLINE_RETURN
+  if (instrs[b].flags & I_RETURN) {
+    /* cmpwi r3,-1 */
+    CMPI(0, PPC_REG_RET, -1);
+    /* bne .+20 */
+    BC(4, 2, 5);
+    /* lwz r0, 36(r1) */
+    LWZ(0, 1, 36);
+    /* addi r1, r1, 32 */
+    ADDI(1, 1, 32);
+    /* mtlr r0 */
+    MTSPR(0, PPC_SPREG_LR);
+    /* blr */
+    BCLR(20, 0);
+
+    if ((b + F_OFFSET) == F_RETURN_IF_TRUE) {
+      /* Kludge. We must check if the ret addr is
+       * orig_addr + JUMP_EPILOGUE_SIZE. */
+
+      /* mflr r0 */
+      MFSPR(0, PPC_SPREG_LR);
+      /* subf r0, r0, r3 */
+      SUBF(0, 0, PPC_REG_RET);
+      /* cmplwi r0, JUMP_EPILOGUE_SIZE */
+      CMPLI(0, 0, JUMP_EPILOGUE_SIZE*4);
+      /* beq .+12 */
+      BC(12, 2, 3);
+    }
+  }
+#endif
 #ifdef OPCODE_RETURN_JUMPADDR
   if (instrs[b].flags & I_JUMP) {
     /* This is the code that JUMP_EPILOGUE_SIZE compensates for. */
@@ -476,6 +533,12 @@ void ins_f_byte(unsigned int b)
     MTSPR(PPC_REG_RET, PPC_SPREG_LR);
     /* blr */
     BCLR(20, 0);
+
+#ifdef OPCODE_INLINE_RETURN
+    if (b == F_CATCH - F_OFFSET) {
+      Pike_compiler->new_program->program[rel_addr] += (PIKE_PC - rel_addr)*4;
+    }
+#endif
   }
 #endif
 }
