@@ -3147,8 +3147,9 @@ PMOD_EXPORT void apply(struct object *o, const char *fun, int args)
 
 PMOD_EXPORT void apply_svalue(struct svalue *s, INT32 args)
 {
-  if(TYPEOF(*s) == T_INT)
+  if(IS_UNDEFINED(s))
   {
+    /* FIXME: Why? cf LysLysKOM 22891031. */
     pop_n_elems(args);
     push_int(0);
   }else{
@@ -3352,7 +3353,11 @@ void gdb_backtrace (
 	if(of) {
           tmp = of->locals - f->locals;
         } else {
+#ifdef PIKE_THREADS
           tmp = ts->state.stack_pointer - f->locals;
+#else
+	  tmp = Pike_sp - f->locals;
+#endif
         }
         args = (INT32)tmp;
 	args = MAXIMUM(MINIMUM(args, f->num_args),0);
