@@ -1,4 +1,4 @@
-#line 1 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
+#line 1 "/Users/hww3/devel/pike/src/interpret_functions.h"
 /*
 || This file is part of Pike. For copyright information see COPYRIGHT.
 || Pike is distributed under GPL, LGPL and MPL. See the file COPYING
@@ -280,12 +280,12 @@ OPCODE1_TAIL(F_MARK_AND_STRING, "mark & string", I_UPDATE_SP|I_UPDATE_M_SP, {
     print_return_value();
   };
 })
-#line 277 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
+#line 277 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE1(F_STRING, "string", I_UPDATE_SP, {
     ref_push_string(Pike_fp->context->prog->strings[arg1]);
     print_return_value();
   })
-#line 281 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
+#line 281 "/Users/hww3/devel/pike/src/interpret_functions.h"
 
 
 
@@ -362,13 +362,13 @@ OPCODE1_TAIL(F_MARK_AND_GLOBAL, "mark & global", I_UPDATE_SP|I_UPDATE_M_SP, {
     print_return_value();
   };
 })
-#line 351 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
+#line 351 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE1(F_GLOBAL, "global", I_UPDATE_SP, {
     low_index_current_object_no_free(Pike_sp, arg1);
     Pike_sp++;
     print_return_value();
   })
-#line 356 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
+#line 356 "/Users/hww3/devel/pike/src/interpret_functions.h"
 
 
 OPCODE1(F_PRIVATE_GLOBAL, "global <private>", I_UPDATE_SP, {
@@ -539,7 +539,7 @@ OPCODE2_TAIL(F_MARK_AND_EXTERNAL, "mark & external", I_UPDATE_SP|I_UPDATE_M_SP,
     print_return_value();
   };
 })
-#line 499 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
+#line 499 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE2(F_EXTERNAL,"external", I_UPDATE_SP, {
     LOCAL_VAR(struct external_variable_context loc);
 
@@ -566,7 +566,7 @@ OPCODE2(F_EXTERNAL,"external", I_UPDATE_SP, {
     }
     print_return_value();
   })
-#line 525 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
+#line 525 "/Users/hww3/devel/pike/src/interpret_functions.h"
 
 
 OPCODE2(F_EXTERNAL_LVALUE, "& external", I_UPDATE_SP, {
@@ -1334,18 +1334,18 @@ OPCODE0_TAIL(F_MARK2, "mark mark", I_UPDATE_M_SP, {
     };
   };
 })
-#line 1285 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
+#line 1285 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE0_TAIL(F_SYNCH_MARK, "synch mark", I_UPDATE_M_SP, {
 
     {
       *(Pike_mark_sp++)=Pike_sp;
     };
   })
-#line 1287 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
+#line 1287 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE0(F_MARK, "mark", I_UPDATE_M_SP, {
       *(Pike_mark_sp++)=Pike_sp;
     })
-#line 1291 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
+#line 1291 "/Users/hww3/devel/pike/src/interpret_functions.h"
 
 
 OPCODE1(F_MARK_X, "mark Pike_sp-X", I_UPDATE_M_SP, {
@@ -1382,7 +1382,7 @@ OPCODE0_TAIL(F_CLEANUP_SYNCH_MARK, "cleanup synch mark", I_UPDATE_SP|I_UPDATE_M_
     }
   };
 })
-#line 1309 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
+#line 1309 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE0(F_POP_SYNCH_MARK, "pop synch mark", I_UPDATE_SP|I_UPDATE_M_SP, {
     if (d_flag) {
       if (Pike_mark_sp <= Pike_interpreter.mark_stack) {
@@ -1400,7 +1400,7 @@ OPCODE0(F_POP_SYNCH_MARK, "pop synch mark", I_UPDATE_SP|I_UPDATE_M_SP, {
       }
     }
   })
-#line 1326 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
+#line 1326 "/Users/hww3/devel/pike/src/interpret_functions.h"
 
 
 OPCODE0(F_CLEAR_STRING_SUBTYPE, "clear string subtype", 0, {
@@ -1433,7 +1433,7 @@ OPCODE2_BRANCH(F_BRANCH_IF_NOT_LOCAL_ARROW, "branch if !local->x", 0, {
     pop_stack();
   };
 })
-#line 1348 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
+#line 1348 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE0_TAILBRANCH(F_BRANCH_WHEN_ZERO, "branch if zero", I_UPDATE_SP, {
     if(!UNSAFE_IS_ZERO(Pike_sp-1))
     {
@@ -1443,7 +1443,7 @@ OPCODE0_TAILBRANCH(F_BRANCH_WHEN_ZERO, "branch if zero", I_UPDATE_SP, {
     }
     pop_stack();
   })
-#line 1357 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
+#line 1357 "/Users/hww3/devel/pike/src/interpret_functions.h"
 
 
 OPCODE0_BRANCH(F_QUICK_BRANCH_WHEN_ZERO, "(Q) branch if zero", I_UPDATE_SP, {
@@ -3055,11 +3055,11 @@ OPCODE1_PTRJUMP(F_COND_RECUR, "recur if not overloaded", I_UPDATE_ALL, {
     DO_RECUR(0);
   };
 })
-#line 2964 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
+#line 2964 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE0_TAILPTRJUMP(F_RECUR, "recur", I_UPDATE_ALL, {
     DO_RECUR(0);
   })
-#line 2967 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
+#line 2967 "/Users/hww3/devel/pike/src/interpret_functions.h"
 
 
 /* Ugly code duplication */
