@@ -1,4 +1,4 @@
-#line 204 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
+#line 204 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE0(F_UNDEFINED, "push UNDEFINED", I_UPDATE_SP)
 
 
@@ -37,48 +37,17 @@ OPCODE1(F_NUMBER, "push int", I_UPDATE_SP)
 
 
 OPCODE2(F_NUMBER64, "push 64-bit int", I_UPDATE_SP)
-
-
-
-
-
-
-
-
-
-
+#line 252 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE1(F_NEG_NUMBER, "push -int", I_UPDATE_SP)
 
 
 
 OPCODE1(F_CONSTANT, "constant", I_UPDATE_SP)
-
-
-
-
-
-
-
-
+#line 265 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE2(F_REARRANGE, "rearrange", 0)
-
-
-
-
-
-
-
-
+#line 274 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE1_TAIL(F_MARK_AND_STRING, "mark & string", I_UPDATE_SP|I_UPDATE_M_SP)OPCODE1(F_STRING, "string", I_UPDATE_SP)
-
-
-
-
-
-
-
-
-
+#line 284 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE1(F_ARROW_STRING, "->string", I_UPDATE_SP)
 
 
@@ -86,9 +55,7 @@ OPCODE1(F_ARROW_STRING, "->string", I_UPDATE_SP)
 
 
 OPCODE1(F_LOOKUP_LFUN, "->lfun", 0)
-#line 317 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
+#line 319 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE1(F_LFUN, "local function", I_UPDATE_SP)
 
 
@@ -96,60 +63,25 @@ OPCODE1(F_LFUN, "local function", I_UPDATE_SP)
 
 
 OPCODE2(F_TRAMPOLINE, "trampoline", I_UPDATE_SP)
-#line 344 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
-
-
+#line 348 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE1_TAIL(F_MARK_AND_GLOBAL, "mark & global", I_UPDATE_SP|I_UPDATE_M_SP)OPCODE1(F_GLOBAL, "global", I_UPDATE_SP)
-
-
-
-
-
-
-
-
-
+#line 358 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE1(F_PRIVATE_GLOBAL, "global <private>", I_UPDATE_SP)
-
-
-
-
-
-
-
-
-
+#line 368 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE2(F_PRIVATE_IF_DIRECT_GLOBAL, "global <private if direct>", I_UPDATE_SP)
-#line 387 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
+#line 389 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE2(F_ASSIGN_PRIVATE_IF_DIRECT_GLOBAL, "assign global <private if direct>", 0)
-#line 405 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
+#line 407 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE2(F_ASSIGN_PRIVATE_TYPED_GLOBAL_AND_POP, "assign global <private,typed> and pop", I_UPDATE_SP)
-#line 417 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
-
+#line 420 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE2(F_ASSIGN_PRIVATE_TYPED_GLOBAL, "assign global <private,typed>", 0)
-#line 465 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
+#line 465 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE2(F_PRIVATE_TYPED_GLOBAL, "global <private,typed>", I_UPDATE_SP)
-#line 492 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
-
-
+#line 496 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE2_TAIL(F_MARK_AND_EXTERNAL, "mark & external", I_UPDATE_SP|I_UPDATE_M_SP)OPCODE2(F_EXTERNAL, "external", I_UPDATE_SP)
-#line 525 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
+#line 527 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE2(F_EXTERNAL_LVALUE, "& external", I_UPDATE_SP)
-#line 546 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
+#line 548 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE1(F_MARK_AND_LOCAL, "mark & local", I_UPDATE_SP|I_UPDATE_M_SP)
 
 
@@ -191,137 +123,65 @@ OPCODE1(F_LOCAL_LVALUE, "& local", I_UPDATE_SP)
 
 
 OPCODE2(F_LEXICAL_LOCAL, "lexical local", I_UPDATE_SP)
-#line 597 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
+#line 599 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE2(F_LEXICAL_LOCAL_LVALUE, "&lexical local", I_UPDATE_SP)
-#line 609 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
+#line 611 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE1(F_ARRAY_LVALUE, "[ lvalues ]", I_UPDATE_SP)
-
-
-
-
-
-
-
-
-
+#line 621 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE2(F_CLEAR_N_LOCAL, "clear n local", 0)
-
-
-
-
-
-
-
-
-
+#line 631 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE1(F_CLEAR_LOCAL, "clear local", 0)
 
 
 
 
 OPCODE2(F_ADD_LOCALS_AND_POP, "local += local", 0)
-#line 680 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
+#line 682 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE2(F_ADD_LOCAL_INT_AND_POP, "local += number", 0)
-#line 698 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
+#line 700 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE2(F_ADD_LOCAL_INT, "local += number local", 0)
-#line 717 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
+#line 719 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE1(F_INC_LOCAL, "++local", I_UPDATE_SP)
-#line 733 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
+#line 735 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE1(F_POST_INC_LOCAL, "local++", I_UPDATE_SP)
-#line 749 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
+#line 751 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE1(F_INC_LOCAL_AND_POP, "++local and pop", 0)
-#line 765 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
+#line 767 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE1(F_DEC_LOCAL, "--local", I_UPDATE_SP)
-#line 781 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
+#line 783 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE1(F_POST_DEC_LOCAL, "local--", I_UPDATE_SP)
-#line 797 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
+#line 799 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE1(F_DEC_LOCAL_AND_POP, "--local and pop", 0)
-#line 813 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
-
-
-
-
+#line 819 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE0(F_LTOSVAL, "lvalue to svalue", I_UPDATE_SP)
-#line 850 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
+#line 850 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE0(F_LTOSVAL2_AND_FREE, "ltosval2 and free", I_UPDATE_SP)
-#line 867 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
-
-
-
-
+#line 873 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE0(F_LTOSVAL3_AND_FREE, "ltosval3 and free", I_UPDATE_SP)
-#line 898 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
-
-
-
-
+#line 904 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE0(F_LTOSVAL_AND_FREE, "ltosval and free", I_UPDATE_SP)
-#line 920 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
+#line 922 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE0(F_ADD_TO, "+=", I_UPDATE_SP)
-#line 985 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
+#line 987 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE0(F_ADD_TO_AND_POP, "+= and pop", I_UPDATE_SP)
-#line 1048 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
+#line 1050 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE1(F_GLOBAL_LVALUE, "& global", I_UPDATE_SP)
 
 
 
 
 OPCODE0(F_INC, "++x", I_UPDATE_SP)
-#line 1071 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
+#line 1073 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE0(F_DEC, "--x", I_UPDATE_SP)
-#line 1089 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
+#line 1091 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE0(F_DEC_AND_POP, "x-- and pop", I_UPDATE_SP)
-#line 1106 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
+#line 1108 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE0(F_INC_AND_POP, "x++ and pop", I_UPDATE_SP)
-#line 1123 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
+#line 1125 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE0(F_POST_INC, "x++", I_UPDATE_SP)
-#line 1144 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
+#line 1146 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE0(F_POST_DEC, "x--", I_UPDATE_SP)
-#line 1165 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
+#line 1167 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE1(F_ASSIGN_LOCAL, "assign local", 0)
 
 
@@ -335,14 +195,7 @@ OPCODE0(F_ASSIGN, "assign", I_UPDATE_SP)
 
 
 OPCODE1(F_ASSIGN_INDICES, "assign[]", I_UPDATE_SP)
-
-
-
-
-
-
-
-
+#line 1188 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE1(F_ASSIGN_ALL_INDICES, "assign[*]", I_UPDATE_SP)
 
 
@@ -351,14 +204,7 @@ OPCODE1(F_ASSIGN_ALL_INDICES, "assign[*]", I_UPDATE_SP)
 
 
 OPCODE2(F_APPLY_ASSIGN_LOCAL_AND_POP, "apply, assign local and pop", I_UPDATE_SP|I_UPDATE_M_SP)
-
-
-
-
-
-
-
-
+#line 1204 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE2(F_APPLY_ASSIGN_LOCAL, "apply, assign local", I_UPDATE_ALL)
 
 
@@ -395,30 +241,11 @@ OPCODE1(F_ASSIGN_GLOBAL_AND_POP, "assign global and pop", I_UPDATE_SP)
 
 
 OPCODE1(F_ASSIGN_PRIVATE_GLOBAL_AND_POP, "assign private global and pop", I_UPDATE_SP)
-#line 1249 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
+#line 1251 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE1(F_ASSIGN_PRIVATE_GLOBAL, "assign private global", I_UPDATE_SP)
-
-
-
-
-
-
-
-
-
+#line 1261 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE2(F_ASSIGN_GLOBAL_NUMBER_AND_POP, "assign global number and pop", 0)
-
-
-
-
-
-
-
-
-
-
+#line 1272 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE0(F_POP_VALUE, "pop", I_UPDATE_SP)
 
 
@@ -428,9 +255,7 @@ OPCODE1(F_POP_N_ELEMS, "pop_n_elems", I_UPDATE_SP)
 
 
 OPCODE0_TAIL(F_MARK2, "mark mark", I_UPDATE_M_SP)OPCODE0_TAIL(F_SYNCH_MARK, "synch mark", I_UPDATE_M_SP)OPCODE0(F_MARK, "mark", I_UPDATE_M_SP)
-#line 1291 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
+#line 1293 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE1(F_MARK_X, "mark Pike_sp-X", I_UPDATE_M_SP)
 
 
@@ -447,9 +272,7 @@ OPCODE0(F_POP_TO_MARK, "pop to mark", I_UPDATE_SP|I_UPDATE_M_SP)
 
 
 OPCODE0_TAIL(F_CLEANUP_SYNCH_MARK, "cleanup synch mark", I_UPDATE_SP|I_UPDATE_M_SP)OPCODE0(F_POP_SYNCH_MARK, "pop synch mark", I_UPDATE_SP|I_UPDATE_M_SP)
-#line 1326 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
+#line 1328 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE0(F_CLEAR_STRING_SUBTYPE, "clear string subtype", 0)
 
 
@@ -460,54 +283,19 @@ OPCODE0_BRANCH(F_BRANCH, "branch", 0)
 
 
 OPCODE2_BRANCH(F_BRANCH_IF_NOT_LOCAL_ARROW, "branch if !local->x", 0)OPCODE0_TAILBRANCH(F_BRANCH_WHEN_ZERO, "branch if zero", I_UPDATE_SP)
-#line 1357 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
+#line 1359 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE0_BRANCH(F_QUICK_BRANCH_WHEN_ZERO, "(Q) branch if zero", I_UPDATE_SP)
-
-
-
-
-
-
-
-
-
+#line 1369 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE0_BRANCH(F_QUICK_BRANCH_WHEN_NON_ZERO, "(Q) branch if not zero", I_UPDATE_SP)
-
-
-
-
-
-
-
-
-
+#line 1379 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE0_BRANCH(F_BRANCH_WHEN_NON_ZERO, "branch if not zero", I_UPDATE_SP)
-
-
-
-
-
-
-
-
-
+#line 1389 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE1_BRANCH(F_BRANCH_IF_TYPE_IS_NOT, "branch if type is !=", I_UPDATE_SP)
-#line 1414 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
+#line 1416 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE1_BRANCH(F_BRANCH_IF_LOCAL, "branch if local", 0)
-
-
-
-
-
-
-
-
+#line 1425 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE1_BRANCH(F_BRANCH_IF_NOT_LOCAL, "branch if !local", 0)
-#line 1444 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
+#line 1444 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE0_BRANCH(F_BRANCH_WHEN_EQ, "branch if ==", I_UPDATE_SP)
 
 OPCODE0_BRANCH(F_BRANCH_WHEN_NE, "branch if !=", I_UPDATE_SP)
@@ -521,55 +309,19 @@ OPCODE0_BRANCH(F_BRANCH_WHEN_GT, "branch if >", I_UPDATE_SP)
 OPCODE0_BRANCH(F_BRANCH_WHEN_GE, "branch if >=", I_UPDATE_SP)
 
 OPCODE0_BRANCH(F_BRANCH_AND_POP_WHEN_ZERO, "branch & pop if zero", 0)
-
-
-
-
-
-
-
-
-
+#line 1461 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE0_BRANCH(F_BRANCH_AND_POP_WHEN_NON_ZERO, "branch & pop if !zero", 0)
-
-
-
-
-
-
-
-
-
+#line 1471 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE0_BRANCH(F_LAND, "&&", I_UPDATE_SP)
-
-
-
-
-
-
-
-
-
+#line 1481 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE0_BRANCH(F_LOR, "||", I_UPDATE_SP)
-
-
-
-
-
-
-
-
-
+#line 1491 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE0_BRANCH(F_EQ_OR, "==||", I_UPDATE_SP)
-#line 1501 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
+#line 1503 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE0_BRANCH(F_EQ_AND, "==&&", I_UPDATE_SP)
-#line 1522 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
+#line 1522 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE0_PTRJUMP(F_CATCH, "catch", I_UPDATE_ALL|I_RETURN)
-#line 1637 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
+#line 1639 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE0(F_ESCAPE_CATCH, "escape catch", 0)
 
 
@@ -580,15 +332,11 @@ OPCODE0(F_EXIT_CATCH, "exit catch", I_UPDATE_SP)
 
 
 OPCODE1_JUMP(F_SWITCH, "switch", I_UPDATE_ALL)
-#line 1661 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
+#line 1663 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE1_JUMP(F_SWITCH_ON_INDEX, "switch on index", I_UPDATE_ALL)
-#line 1680 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
+#line 1682 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE2_JUMP(F_SWITCH_ON_LOCAL, "switch on local", 0)
-#line 1726 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
+#line 1726 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE0_BRANCH(F_INC_LOOP, "++Loop", 0)
 
 OPCODE0_BRANCH(F_DEC_LOOP, "--Loop", 0)
@@ -596,35 +344,22 @@ OPCODE0_BRANCH(F_DEC_LOOP, "--Loop", 0)
 OPCODE0_BRANCH(F_INC_NEQ_LOOP, "++Loop!=", 0)
 
 OPCODE0_BRANCH(F_DEC_NEQ_LOOP, "--Loop!=", 0)
-#line 1742 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
+#line 1742 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE0_BRANCH(F_LOOP, "loop", I_UPDATE_SP)
-#line 1752 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
+#line 1754 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE0_BRANCH(F_FOREACH, "foreach", 0)
-#line 1772 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
+#line 1774 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE0(F_MAKE_ITERATOR, "get_iterator", 0)
 
 
 
 
 OPCODE0_BRANCH(F_FOREACH_START, "foreach start", 0)
-#line 1790 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
-
+#line 1793 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE0_BRANCH(F_FOREACH_LOOP, "foreach loop", 0)
-#line 1805 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
-
+#line 1808 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE1_RETURN(F_RETURN_LOCAL, "return local", I_UPDATE_SP|I_UPDATE_FP)
-#line 1825 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
-
+#line 1828 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE0_RETURN(F_RETURN_IF_TRUE, "return if true", I_UPDATE_SP|I_UPDATE_FP)
 
 
@@ -650,20 +385,15 @@ OPCODE0_RETURN(F_DUMB_RETURN, "dumb return", I_UPDATE_FP)
 
 
 OPCODE0(F_NEGATE, "unary minus", 0)
-#line 1872 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
+#line 1874 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE0_ALIAS(F_COMPL, "~", 0, o_compl)
 
 OPCODE0(F_NOT, "!", 0)
-#line 1900 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
-
+#line 1903 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE0_ALIAS(F_LSH, "<<", I_UPDATE_SP, o_lsh)
 
 OPCODE0_ALIAS(F_RSH, ">>", I_UPDATE_SP, o_rsh)
-#line 1913 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
+#line 1913 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE0(F_EQ, "==", I_UPDATE_SP)
 
 OPCODE0(F_NE, "!=", I_UPDATE_SP)
@@ -683,15 +413,9 @@ OPCODE0(F_ADD, "+", I_UPDATE_SP)
 
 
 OPCODE0(F_ADD_INTS, "int+int", I_UPDATE_SP)
-#line 1937 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
-
+#line 1940 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE0(F_ADD_FLOATS, "float+float", I_UPDATE_SP)
-#line 1949 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
-
+#line 1952 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE0_ALIAS(F_SUBTRACT, "-", I_UPDATE_SP, o_subtract)
 
 OPCODE0_ALIAS(F_AND, "&", I_UPDATE_SP, o_and)
@@ -752,17 +476,11 @@ OPCODE1(F_LSH_INT, "<< int", 0)
 
 
 OPCODE1(F_ADD_INT, "add integer", 0)
-#line 2015 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
+#line 2017 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE1(F_ADD_NEG_INT, "add -integer", 0)
-#line 2027 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
+#line 2029 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE0(F_PUSH_ARRAY, "@", I_UPDATE_SP)
-#line 2060 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
+#line 2062 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE0(F_APPEND_ARRAY, "append array", I_UPDATE_SP|I_UPDATE_M_SP)
 
 
@@ -780,37 +498,15 @@ OPCODE2(F_LOCAL_LOCAL_INDEX, "local[local]", I_UPDATE_SP)
 
 
 OPCODE1(F_LOCAL_INDEX, "local index", 0)
-
-
-
-
-
-
-
-
-
+#line 2088 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE2(F_GLOBAL_LOCAL_INDEX, "global[local]", I_UPDATE_SP)
-#line 2098 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
+#line 2100 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE2(F_LOCAL_ARROW, "local->x", I_UPDATE_SP)
-
-
-
-
-
-
-
-
-
+#line 2110 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE1(F_ARROW, "->x", 0)
-#line 2119 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
+#line 2121 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE1(F_STRING_INDEX, "string index", 0)
-#line 2130 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
+#line 2132 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE1(F_POS_INT_INDEX, "int index", 0)
 
 
@@ -850,10 +546,7 @@ OPCODE0_ALIAS(F_CAST_TO_INT, "cast_to_int", 0, o_cast_to_int)
 OPCODE0_ALIAS(F_CAST_TO_STRING, "cast_to_string", 0, o_cast_to_string)
 
 OPCODE0(F_SOFT_CAST, "soft cast", I_UPDATE_SP)
-#line 2187 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
-
+#line 2190 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE1_ALIAS(F_RANGE, "range", I_UPDATE_SP, o_range2)
 
 OPCODE0(F_COPY_VALUE, "copy_value", 0)
@@ -865,9 +558,7 @@ OPCODE0(F_COPY_VALUE, "copy_value", 0)
 
 
 OPCODE0(F_INDIRECT, "indirect", I_UPDATE_SP)
-#line 2220 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
+#line 2222 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE0(F_SIZEOF, "sizeof", 0)
 
 
@@ -889,50 +580,32 @@ OPCODE1(F_SIZEOF_LOCAL_STRING, "sizeof local string", I_UPDATE_SP)
 
 
 OPCODE2_ALIAS(F_SSCANF, "sscanf", I_UPDATE_SP, o_sscanf)
-#line 2343 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
+#line 2343 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE1_JUMP(F_CALL_LFUN, "call lfun", I_UPDATE_ALL)
-#line 2357 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
+#line 2359 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE2_JUMP(F_CALL_LFUN_N, "call lfun <n>", I_UPDATE_ALL)
-#line 2373 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
+#line 2375 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE1_JUMP(F_CALL_LFUN_AND_POP, "call lfun & pop", I_UPDATE_ALL)
-#line 2390 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
+#line 2392 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE1_RETURN(F_CALL_LFUN_AND_RETURN, "call lfun & return", I_UPDATE_ALL)
-#line 2404 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
+#line 2406 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE1_JUMP(F_MARK_CALL_LFUN, "mark, call lfun", I_UPDATE_ALL)
-#line 2416 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
+#line 2418 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE1_JUMP(F_MARK_CALL_LFUN_AND_POP, "mark, call lfun & pop", I_UPDATE_ALL)
-#line 2432 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
+#line 2434 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE1_RETURN(F_MARK_CALL_LFUN_AND_RETURN, "mark, call lfun & return", I_UPDATE_ALL)
-#line 2447 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
+#line 2449 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE1_JUMP(F_APPLY, "apply", I_UPDATE_ALL)OPCODE1_JUMP(F_APPLY_AND_POP, "apply" " & pop", I_UPDATE_ALL)OPCODE1_RETURN(F_APPLY_AND_RETURN, "apply" " & return", I_UPDATE_ALL)OPCODE1_JUMP(F_MARK_APPLY, "mark, " "apply", I_UPDATE_ALL)OPCODE1_JUMP(F_MARK_APPLY_AND_POP, "mark, " "apply" " & pop", I_UPDATE_ALL)OPCODE1_RETURN(F_MARK_APPLY_AND_RETURN, "mark, " "apply" " & return", I_UPDATE_ALL)
 
 
 OPCODE0_JUMP(F_CALL_FUNCTION, "call function", I_UPDATE_ALL)OPCODE0_JUMP(F_CALL_FUNCTION_AND_POP, "call function" " & pop", I_UPDATE_ALL)OPCODE0_RETURN(F_CALL_FUNCTION_AND_RETURN, "call function" " & return", I_UPDATE_ALL)
 
 OPCODE1_JUMP(F_CALL_OTHER, "call other", I_UPDATE_ALL)
-#line 2510 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
+#line 2512 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE1_JUMP(F_CALL_OTHER_AND_POP, "call other & pop", I_UPDATE_ALL)
-#line 2572 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
+#line 2574 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE1_RETURN(F_CALL_OTHER_AND_RETURN, "call other & return", I_UPDATE_ALL)
-#line 2700 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
+#line 2700 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE1(F_CALL_BUILTIN, "call builtin", I_UPDATE_ALL)
 
 
@@ -990,19 +663,12 @@ OPCODE1(F_CALL_BUILTIN1_AND_POP, "call builtin1 & pop", I_UPDATE_ALL)
 
 
 OPCODE1(F_LTOSVAL_CALL_BUILTIN_AND_ASSIGN, "ltosval, call builtin & assign", I_UPDATE_ALL)
-#line 2800 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
+#line 2802 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE1(F_LTOSVAL_CALL_BUILTIN_AND_ASSIGN_POP, "ltosval, call builtin, assign & pop", I_UPDATE_ALL)
-#line 2916 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
+#line 2916 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE1_PTRJUMP(F_COND_RECUR, "recur if not overloaded", I_UPDATE_ALL)OPCODE0_TAILPTRJUMP(F_RECUR, "recur", I_UPDATE_ALL)
-#line 2967 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
-
+#line 2970 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE0_PTRJUMP(F_RECUR_AND_POP, "recur & pop", I_UPDATE_ALL)
-#line 2970 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
 
 
 
@@ -1010,25 +676,15 @@ OPCODE0_PTRJUMP(F_RECUR_AND_POP, "recur & pop", I_UPDATE_ALL)
 
 
 OPCODE0_PTRJUMP(F_TAIL_RECUR, "tail recursion", I_UPDATE_ALL)
-#line 3001 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
+#line 3003 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE1(F_THIS_OBJECT, "this_object", I_UPDATE_SP)
-#line 3019 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
+#line 3021 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE0(F_UNDEFINEDP, "undefinedp", 0)
-#line 3034 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
+#line 3036 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE0(F_DESTRUCTEDP, "destructedp", 0)
-#line 3051 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
+#line 3053 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE0(F_ZERO_TYPE, "zero_type", 0)
-#line 3068 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
+#line 3070 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE0(F_SWAP, "swap", 0)
 
 
@@ -1038,9 +694,7 @@ OPCODE0(F_DUP, "dup", I_UPDATE_SP)
 
 
 OPCODE2(F_THIS, "this", I_UPDATE_SP)
-#line 3098 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
+#line 3100 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE2(F_MAGIC_TYPES, "::_types", I_UPDATE_SP)
 
 
@@ -1055,7 +709,5 @@ OPCODE1(F_PROTECT_STACK, "protect_stack", 0)
 
 
 OPCODE2(F_FILL_STACK, "fill_stack", I_UPDATE_SP)
-#line 3122 "/home/zino/hack/pike8-rel/pike/src/interpret_functions.h"
-
-
+#line 3124 "/Users/hww3/devel/pike/src/interpret_functions.h"
 OPCODE1(F_MARK_AT, "mark_at", I_UPDATE_SP)
