@@ -2,7 +2,6 @@
 || This file is part of Pike. For copyright information see COPYRIGHT.
 || Pike is distributed under GPL, LGPL and MPL. See the file COPYING
 || for more information.
-|| $Id: 09df0ad45969ac92b085b4d7dcd049e7a7d27f68 $
 */
 
 #include "global.h"
@@ -35,12 +34,17 @@ extern struct program *image_program;
 **! module Image
 **! submodule AVS
 **!
+**! An AVS file is a raw (uncompressed) 24 bit image file with alpha.
+**!
+**! The file starts with width and height as 32-bit ingegers, followed
+**! by 4 x width x height bytes of image data. The format is big
+**! endian.
 */
 
 /*
 **! method object decode(string data)
 **! method mapping _decode(string data)
-**! method string encode(object image)
+**! method string encode(object image, object|void alpha)
 **!
 **! Handle encoding and decoding of AVS-X images.
 **! AVS is rather trivial, and not really useful, but:
@@ -90,9 +94,9 @@ void image_avs_f__decode(INT32 args)
     ((struct image *)ao->storage)->img[c] = apix;
   }
   pop_n_elems(args);
-  push_constant_text("image");
+  push_text("image");
   push_object( io );
-  push_constant_text("alpha");
+  push_text("alpha");
   push_object( ao );
   f_aggregate_mapping( 4 );
 }
@@ -100,7 +104,7 @@ void image_avs_f__decode(INT32 args)
 void image_avs_f_decode(INT32 args)
 {
   image_avs_f__decode(args);
-  push_constant_text("image");
+  push_text("image");
   f_index(2);
 }
 
@@ -113,13 +117,20 @@ void image_avs_f_encode(INT32 args )
   int x,y;
   unsigned int *q;
   rgb_group apix = {255, 255, 255};
-  get_all_args( "encode", args, "%o", &io);
+  get_all_args( "encode", args, "%o.%o", &io, &ao);
   
-  if(!(i = (struct image *)get_storage( io, image_program)))
+  if(!(i = get_storage( io, image_program)))
     Pike_error("Wrong argument 1 to Image.AVS.encode\n");
-  
+
+  if(ao) {
+    if (!(a = get_storage( ao, image_program)))
+      Pike_error("Wrong argument 2 to Image.AVS.encode\n");
+    if ((a->xsize != i->xsize) || (a->ysize != i->ysize))
+      Pike_error("Bad size for alpha channel to Image.AVS.encode.\n");
+  }
+
   s = begin_shared_string( i->xsize*i->ysize*4+8 );
-  MEMSET(s->str, 0, s->len );
+  memset(s->str, 0, s->len );
 
   q = (unsigned int *)s->str;
   *(q++) = htonl( i->xsize );
@@ -131,7 +142,7 @@ void image_avs_f_encode(INT32 args )
   for(y=0; y<i->ysize; y++)
     for(x=0; x<i->xsize; x++)
     {
-      register int rv = 0;
+      register unsigned int rv = 0;
       rgb_group pix = *(is++);
       if(as) apix = *(as++);
       rv = ((apix.g<<24)|(pix.r<<16)|(pix.g<<8)|pix.b);
@@ -141,13 +152,14 @@ void image_avs_f_encode(INT32 args )
   push_string( end_shared_string(s) );
 }
 
-void init_image_avs()
+void init_image_avs(void)
 {
   ADD_FUNCTION( "decode",  image_avs_f_decode,  tFunc(tStr,tObj), 0);
   ADD_FUNCTION( "_decode", image_avs_f__decode, tFunc(tStr,tMapping), 0);
-  ADD_FUNCTION( "encode",  image_avs_f_encode,  tFunc(tObj,tStr), 0);
+  ADD_FUNCTION( "encode",  image_avs_f_encode,
+		tFunc(tObj tOr(tObj,tVoid),tStr), 0);
 }
 
-void exit_image_avs()
+void exit_image_avs(void)
 {
 }
