@@ -2,7 +2,6 @@
 || This file is part of Pike. For copyright information see COPYRIGHT.
 || Pike is distributed under GPL, LGPL and MPL. See the file COPYING
 || for more information.
-|| $Id: c6b0d86348bc010246c8f5fb3959c0106b58df46 $
 */
 
 #include "global.h"
@@ -18,6 +17,7 @@
 #include "operators.h"
 #include "builtin_functions.h"
 #include "module_support.h"
+#include "pike_types.h"
 
 
 #include "image.h"
@@ -33,7 +33,7 @@ extern struct program *image_program;
 **! submodule TIM
 **!
 **! 	Handle decoding of TIM images.
-**! 
+**!
 **! 	TIM is the framebuffer format of the PSX game system.
 **! 	It is a simple, uncompressed, truecolor or CLUT format
 **!     with a one bit alpha channel.
@@ -174,7 +174,7 @@ void img_tim_decode(INT32 args, int header_only)
   INT32 attr;
   unsigned int h=0, w=0;
   
-  get_all_args("Image.TIM._decode", args, "%S", &str);
+  get_all_args("_decode", args, "%S", &str);
   clut=s=(unsigned char *)str->str;
   clut+=20;
   len = str->len;
@@ -187,7 +187,7 @@ void img_tim_decode(INT32 args, int header_only)
 
   s += 4; len -= 4;
   
-  push_text("type");
+  ref_push_string(literal_type_string);
   push_text("image/x-tim");
   n++;
   
@@ -287,7 +287,7 @@ void img_tim_decode(INT32 args, int header_only)
     push_int(w);
     push_int(h);
     o=clone_object(image_program,2);
-    img=(struct image*)get_storage(o,image_program);
+    img=get_storage(o,image_program);
     push_object(o);
     n++;
     
@@ -298,7 +298,7 @@ void img_tim_decode(INT32 args, int header_only)
       push_int(w);
       push_int(h);
       o=clone_object(image_program,2);
-      img=(struct image*)get_storage(o,image_program);
+      img=get_storage(o,image_program);
       push_object(o);
       n++;
       
@@ -336,7 +336,7 @@ void image_tim_f__decode(INT32 args)
    img_tim_decode(args,0);
 }
 
-void init_image_tim()
+void init_image_tim(void)
 {
   ADD_FUNCTION( "decode",  image_tim_f_decode,  tFunc(tStr,tObj), 0);
   ADD_FUNCTION( "decode_alpha",  image_tim_f_decode_alpha,  tFunc(tStr,tObj), 0);
@@ -344,6 +344,6 @@ void init_image_tim()
   ADD_FUNCTION( "decode_header", image_tim_f_decode_header, tFunc(tStr,tMapping), 0);
 }
 
-void exit_image_tim()
+void exit_image_tim(void)
 {
 }
