@@ -2,7 +2,6 @@
 || This file is part of Pike. For copyright information see COPYRIGHT.
 || Pike is distributed under GPL, LGPL and MPL. See the file COPYING
 || for more information.
-|| $Id: db7b2e295b2f9c8c4af8926df072ee4423f92975 $
 */
 
 #include "global.h"
@@ -34,7 +33,12 @@ extern struct program *image_program;
  */
 
 /*! @module WBMP
- *! WAP bitmap format - WBMP.
+ *! Wireless Application Protocol Bitmap Format - WAP bitmap format - WBMP.
+ *!
+ *! Wireless Application Protocol Bitmap Format (shortened to Wireless
+ *! Bitmap and with file extension .wbmp) is a monochrome graphics
+ *! file format that was optimized for the extremely low-end mobile
+ *! computing devices that were common in the early days of the mobile web.
  */
 
 struct buffer
@@ -67,7 +71,7 @@ static void read_string( struct buffer *from, unsigned int len, char *to )
 {
   if( from->len < len )
     Pike_error("Invalid data format\n");
-  MEMCPY( from->str, to, len );
+  memcpy( from->str, to, len );
   from->str += len;
   from->len -= len;
 }
@@ -101,9 +105,9 @@ static int wbf_read_int( struct buffer *from )
 
 static void push_ext_header( struct ext_header *eh )
 {
-  push_constant_text( "identifier" );
+  push_text( "identifier" );
   push_string( make_shared_binary_string( eh->name, eh->name_len ) );
-  push_constant_text( "value" );
+  push_text( "value" );
   push_string( make_shared_binary_string( eh->value, eh->value_len ) );
   f_aggregate_mapping( 4 );
 }
@@ -122,7 +126,7 @@ static struct wbf_header decode_header( struct buffer *data )
 {
   struct wbf_header res;
   ONERROR err;
-  MEMSET( &res, 0, sizeof(res) );
+  memset( &res, 0, sizeof(res) );
   res.type = wbf_read_int( data );
   res.fix_header_field = read_uchar( data );
   SET_ONERROR(err, free_wbf_header_contents, &res);
@@ -144,8 +148,7 @@ static struct wbf_header decode_header( struct buffer *data )
          {
            struct ext_header *eh;
            q = read_uchar( data );
-           eh = xalloc( sizeof( struct ext_header ) );
-           MEMSET( eh, 0, sizeof( struct ext_header ) );
+           eh = xcalloc( 1, sizeof( struct ext_header ) );
            eh->next = res.first_ext_header;
            res.first_ext_header = eh;
            eh->name_len = ((q>>4) & 0x7) + 1;
@@ -174,7 +177,7 @@ static void low_image_f_wbf_decode_type0( struct wbf_header *wh,
   push_int( wh->width );
   push_int( wh->height );
   io = clone_object( image_program, 2 );
-  i = (struct image*)get_storage(io,image_program);
+  i = get_storage(io,image_program);
   id = i->img;
 
   white.r = 255;
@@ -236,33 +239,33 @@ static void low_image_f_wbf_decode( int args, int mode )
         return;
 
       case 1: /* Image and header */
-        push_constant_text( "image" );
+        push_text( "image" );
         low_image_f_wbf_decode_type0( &wh, &buff );
         map_num_elems++;
         
       case 0: /* Header only */
-        push_constant_text( "format" );
-        push_constant_text( "image/x-wap.wbmp; type=0" );
+        push_text( "format" );
+        push_text( "image/x-wap.wbmp; type=0" );
         map_num_elems++;
         
-        push_constant_text( "xsize" );
+        push_text( "xsize" );
         push_int( wh.width );
         map_num_elems++;
 
-        push_constant_text( "ysize" );
+        push_text( "ysize" );
         push_int( wh.height );
         map_num_elems++;
 
         if( wh.fix_header_field )
         {
-          push_constant_text( "fix_header_field" );
+          push_text( "fix_header_field" );
           push_int( wh.fix_header_field );
           map_num_elems++;
         }
 
         if( wh.ext_header_field )
         {
-          push_constant_text( "ext_header_field" );
+          push_text( "ext_header_field" );
           push_int( wh.ext_header_field );
           map_num_elems++;
         }
@@ -295,10 +298,9 @@ static void low_image_f_wbf_decode( int args, int mode )
   }
 }
 
-/*! @decl object decode(string image)
+/*! @decl Image.Image decode(string image)
  *!
- *! @fixme
- *!   Document this function.
+ *! Decode the given image
  */
 
 static void image_f_wbf_decode( int args )
@@ -308,8 +310,17 @@ static void image_f_wbf_decode( int args )
 
 /*! @decl mapping _decode(string image)
  *!
- *! @fixme
- *!   Document this function.
+ *! Decode the given image
+ *! @returns
+ *!   @mapping
+ *!     @member Image.Image "img"
+ *!     @member string "format"
+ *!       The MIME type and encoding for the image, e.g. "image/x-wap.wbmp; type=0".
+ *!     @member int "xsize"
+ *!     @member int "ysize"
+ *!     @member int "fix_header_field"
+ *!     @member int "ext_header_field"
+ *!  @endmapping
  */
 
 static void image_f_wbf__decode( int args )
@@ -362,8 +373,7 @@ static void push_wap_type0_image_data( struct image *i )
   int x, y;
   unsigned char *data, *p;
   rgb_group *is;
-  data = xalloc( i->ysize * (i->xsize+7)/8 );
-  MEMSET( data, 0, i->ysize * (i->xsize+7)/8 );
+  data = xcalloc( i->ysize, (i->xsize+7)/8 );
   is = i->img;
   for( y = 0; y<i->ysize; y++ )
   {
@@ -382,8 +392,8 @@ static void push_wap_type0_image_data( struct image *i )
 /*! @decl string encode(object image, void|mapping args)
  *! @decl string _encode(object image, void|mapping args)
  *!
- *! @fixme
- *!  Document this function.
+ *! Encode the given image as a WBMP image. All pixels that are not
+ *! black will be encoded as white.
  */
 
 static void image_f_wbf_encode( int args )
@@ -397,16 +407,16 @@ static void image_f_wbf_encode( int args )
     Pike_error("No image given to encode.\n");
   if( args > 2 )
     Pike_error("Too many arguments to encode.\n");
-  if( sp[-args].type != T_OBJECT )
+  if( TYPEOF(sp[-args]) != T_OBJECT )
     Pike_error("No image given to encode.\n");
 
   o = sp[-args].u.object;
-  i = (struct image*)get_storage(o,image_program);
+  i = get_storage(o,image_program);
   if(!i)
     Pike_error("Wrong type object argument\n");
   if( args == 2 )
   {
-    if( sp[-args+1].type != T_MAPPING )
+    if( TYPEOF(sp[-args+1]) != T_MAPPING )
       Pike_error("Wrong type for argument 2.\n");
     options = sp[-args+1].u.mapping;
   }
@@ -429,7 +439,7 @@ static void image_f_wbf_encode( int args )
 /*! @endmodule
  */
 
-void init_image_wbf()
+void init_image_wbf(void)
 {
   ADD_FUNCTION( "encode", image_f_wbf_encode,
 		tFunc(tObj tOr(tVoid,tMapping),tStr), 0);
@@ -441,6 +451,6 @@ void init_image_wbf()
 		tFunc(tStr,tMapping), 0);
 }
 
-void exit_image_wbf()
+void exit_image_wbf(void)
 {
 }
