@@ -2,7 +2,6 @@
 || This file is part of Pike. For copyright information see COPYRIGHT.
 || Pike is distributed under GPL, LGPL and MPL. See the file COPYING
 || for more information.
-|| $Id: c7231f731128ab63319f6a67961f883bf6361ad2 $
 */
 
 #define NO_PIKE_SHORTHAND
@@ -34,6 +33,12 @@ extern struct program *image_program;
 **! module Image
 **! submodule XBM
 **!
+**! Decode and encode X BitMap images.
+**!
+**! This is a monochrome format historically used in the X Window
+**! System. It is a plain text image format, mainly used for storing
+**! cursor and icon bitmaps used in the X GUI. The XBM format was
+**! officially deprecated in 1989, replaced with the XPM format.
 */
 
 
@@ -116,7 +121,7 @@ static struct object *load_xbm( struct pike_string *data )
   push_int( width );
   push_int( height );
   io = clone_object( image_program, 2 );
-  dest = ((struct image *)get_storage(io, image_program))->img;
+  dest = ((struct image*)get_storage(io, image_program))->img;
   /* .. the code below asumes black if the read fails.. */
   for(y=0; y<height; y++)
   {
@@ -250,7 +255,7 @@ static void image_xbm__decode( INT32 args )
 
   if (args>1)
   {
-    if (Pike_sp[1-args].type!=PIKE_T_MAPPING)
+    if (TYPEOF(Pike_sp[1-args]) != PIKE_T_MAPPING)
       Pike_error("Image.XBM._decode: illegal argument 2\n");
       
     push_svalue(Pike_sp+1-args);
@@ -258,11 +263,11 @@ static void image_xbm__decode( INT32 args )
     f_index(2);
     if(!UNSAFE_IS_ZERO(Pike_sp-1))
     {
-      if(Pike_sp[-1].type != PIKE_T_ARRAY || Pike_sp[-1].u.array->size != 3)
+      if(TYPEOF(Pike_sp[-1]) != PIKE_T_ARRAY || Pike_sp[-1].u.array->size != 3)
         Pike_error("Wrong type for foreground. Should be array(int(0..255))"
               " with 3 elements\n");
       for(ele=0; ele<3; ele++)
-        if(Pike_sp[-1].u.array->item[ele].type != PIKE_T_INT
+        if(TYPEOF(Pike_sp[-1].u.array->item[ele]) != PIKE_T_INT
            ||Pike_sp[-1].u.array->item[ele].u.integer < 0
            ||Pike_sp[-1].u.array->item[ele].u.integer > 255)
           Pike_error("Wrong type for foreground. Should be array(int(0..255))"
@@ -276,11 +281,11 @@ static void image_xbm__decode( INT32 args )
     f_index(2);
     if(!UNSAFE_IS_ZERO(Pike_sp-1))
     {
-      if(Pike_sp[-1].type != PIKE_T_ARRAY || Pike_sp[-1].u.array->size != 3)
+      if(TYPEOF(Pike_sp[-1]) != PIKE_T_ARRAY || Pike_sp[-1].u.array->size != 3)
         Pike_error("Wrong type for background. Should be array(int(0..255))"
               " with 3 elements\n");
       for(ele=0; ele<3; ele++)
-        if(Pike_sp[-1].u.array->item[ele].type != PIKE_T_INT
+        if(TYPEOF(Pike_sp[-1].u.array->item[ele]) != PIKE_T_INT
            ||Pike_sp[-1].u.array->item[ele].u.integer < 0
            ||Pike_sp[-1].u.array->item[ele].u.integer > 255)
           Pike_error("Wrong type for background. Should be array(int(0..255))"
@@ -342,9 +347,9 @@ static void image_xbm__decode( INT32 args )
   }
   
   pop_n_elems(args);
-  push_constant_text( "alpha" );
+  push_text( "alpha" );
   push_object( a );
-    push_constant_text( "image" );
+    push_text( "image" );
   if(i)
     push_object( i );
   else
@@ -378,9 +383,8 @@ void image_xbm_encode( INT32 args )
   if (!args)
     Pike_error("Image.XBM.encode: too few arguments\n");
    
-  if (Pike_sp[-args].type!=PIKE_T_OBJECT ||
-      !(img=(struct image*)
-        get_storage(Pike_sp[-args].u.object,image_program)))
+  if (TYPEOF(Pike_sp[-args]) != PIKE_T_OBJECT ||
+      !(img=get_storage(Pike_sp[-args].u.object,image_program)))
     Pike_error("Image.XBM.encode: illegal argument 1\n");
    
   if (!img->img)
@@ -388,13 +392,13 @@ void image_xbm_encode( INT32 args )
 
   if (args>1)
   {
-    if (Pike_sp[1-args].type!=PIKE_T_MAPPING)
+    if (TYPEOF(Pike_sp[1-args]) != PIKE_T_MAPPING)
       Pike_error("Image.XBM.encode: illegal argument 2\n");
       
     push_svalue(Pike_sp+1-args);
     ref_push_string(param_name); 
     f_index(2);
-    if(Pike_sp[-1].type == PIKE_T_STRING)
+    if(TYPEOF(Pike_sp[-1]) == PIKE_T_STRING)
     {
       if(Pike_sp[-1].u.string->size_shift)
         Pike_error("The name of the image must be a normal non-wide string (sorry, not my fault)\n");
