@@ -58,6 +58,9 @@
 #endif /* HAVE_MYSQL_ERRMSG_H */
 #endif /* HAVE_ERRMGS_H */
 
+#ifndef HAVE_MY_BOOL
+#define my_bool bool
+#endif
 
 #endif /* HAVE_MYSQL */
 
