@@ -2,7 +2,6 @@
 || This file is part of Pike. For copyright information see COPYRIGHT.
 || Pike is distributed under GPL, LGPL and MPL. See the file COPYING
 || for more information.
-|| $Id: 52722a2a57d1a8cc73e530c95921dde61b77e305 $
 */
 
 /*
@@ -60,7 +59,6 @@
 #include "pike_error.h"
 #include "builtin_functions.h"
 #include "las.h"
-#include "port.h"
 #include "threads.h"
 #include "multiset.h"
 #include "bignum.h"
@@ -121,12 +119,12 @@ static struct svalue mpq_program = SVALUE_INIT_FREE;
  * State maintenance
  */
 
-static void init_res_struct(struct object *o)
+static void init_res_struct(struct object *UNUSED(o))
 {
   memset(PIKE_MYSQL_RES, 0, sizeof(struct precompiled_mysql_result));
 }
 
-static void exit_res_struct(struct object *o)
+static void exit_res_struct(struct object *UNUSED(o))
 {
   if (PIKE_MYSQL_RES->result) {
     mysql_free_result(PIKE_MYSQL_RES->result);
@@ -250,11 +248,14 @@ void mysqlmod_parse_field(MYSQL_FIELD *field, int support_default)
       nbits++;
       push_text("primary_key");
     }
-    if (field->flags & UNIQUE_KEY_FLAG)
-    {
+    if (field->flags & UNIQUE_KEY_FLAG) {
       push_text("unique");
       nbits++;
     }
+    if (field->flags & MULTIPLE_KEY_FLAG) {
+      push_text("multiple_key");
+      nbits++;
+    }
     if (IS_NOT_NULL(field->flags)) {
       nbits++;
       push_text("not_null");
@@ -271,6 +272,26 @@ void mysqlmod_parse_field(MYSQL_FIELD *field, int support_default)
       nbits++;
       push_text("binary");
     }
+    if (field->flags & AUTO_INCREMENT_FLAG) {
+      nbits++;
+      push_text("auto_increment");
+    }
+    if (field->flags & ENUM_FLAG) {
+      nbits++;
+      push_text("enum");
+    }
+    if (field->flags & SET_FLAG) {
+      nbits++;
+      push_text("set");
+    }
+    if (field->flags & UNSIGNED_FLAG) {
+      nbits++;
+      push_text("unsigned");
+    }
+    if (field->flags & NUM_FLAG) {
+      nbits++;
+      push_text("numeric");
+    }
     f_aggregate_multiset(nbits);
 
     push_text("decimals"); push_int(field->decimals);
@@ -317,7 +338,7 @@ static void f_create(INT32 args)
   if (!args) {
     Pike_error("Too few arguments to mysql_result()\n");
   }
-  if (sp[-args].type != T_OBJECT) {
+  if (TYPEOF(sp[-args]) != T_OBJECT) {
     Pike_error("Bad argument 1 to mysql_result()\n");
   }
 
@@ -327,7 +348,7 @@ static void f_create(INT32 args)
   PIKE_MYSQL_RES->typed_mode = 0;
 #endif
   if (args > 1) {
-    if (sp[1-args].type != T_INT) {
+    if (TYPEOF(sp[1-args]) != T_INT) {
       Pike_error("Bad argument 2 to mysql_result()\n");
     }
     PIKE_MYSQL_RES->typed_mode = !!sp[1-args].u.integer;
@@ -406,7 +427,7 @@ static void f_field_seek(INT32 args)
   if (!args) {
     Pike_error("Too few arguments to mysql->field_seek()\n");
   }
-  if (sp[-args].type != T_INT) {
+  if (TYPEOF(sp[-args]) != T_INT) {
     Pike_error("Bad argument 1 to mysql->field_seek()\n");
   }
   if (!PIKE_MYSQL_RES->result) {
@@ -595,7 +616,6 @@ static void f_fetch_row(INT32 args)
 	  switch (field->type) {
 	    /* Integer types */
           case FIELD_TYPE_LONGLONG:
-#ifdef AUTO_BIGNUM
 	    if (
 #ifdef HAVE_MYSQL_FETCH_LENGTHS
 		row_lengths[i]
@@ -607,16 +627,16 @@ static void f_fetch_row(INT32 args)
 	      convert_stack_top_string_to_inumber(10);
 	      break;
 	    }
-#endif
+
 	    /* FALL_THROUGH */
 	  case FIELD_TYPE_TINY:
 	  case FIELD_TYPE_SHORT:
 	  case FIELD_TYPE_LONG:
 	  case FIELD_TYPE_INT24:
-	    push_int(STRTOL(row[i], 0, 10));
+	    push_int(strtol(row[i], 0, 10));
 	    break;
 
-#if defined (HAVE_MYSQL_FETCH_LENGTHS) && defined (AUTO_BIGNUM)
+#if defined (HAVE_MYSQL_FETCH_LENGTHS)
 	  case FIELD_TYPE_BIT:
 	    if (row_lengths[i] <= SIZEOF_LONGEST) {
 	      unsigned LONGEST val = 0;
@@ -643,7 +663,6 @@ static void f_fetch_row(INT32 args)
 	  case FIELD_TYPE_DECIMAL:
 	  case FIELD_TYPE_NEWDECIMAL:
 	    if (!field->decimals) {
-#ifdef AUTO_BIGNUM
 	      if (
 #ifdef HAVE_MYSQL_FETCH_LENGTHS
 		row_lengths[i]
@@ -660,25 +679,24 @@ static void f_fetch_row(INT32 args)
 		convert_stack_top_string_to_inumber(10);
 		break;
 	      }
-#endif
-	      push_int(STRTOL(row[i], 0, 10));
+	      push_int(strtol(row[i], 0, 10));
 	      break;
 	    }
 
 	    /* Fixed-point number with fraction part. Make an mpq. */
 
-	    if (mpq_program.type == PIKE_T_FREE) {
+	    if (TYPEOF(mpq_program) == PIKE_T_FREE) {
 	      push_text ("Gmp.mpq");
 	      SAFE_APPLY_MASTER ("resolv", 1);
-	      if (Pike_sp[-1].type == T_PROGRAM)
+	      if (TYPEOF(Pike_sp[-1]) == T_PROGRAM)
 		move_svalue (&mpq_program, --Pike_sp);
 	      else {
 		pop_stack();
-		mpq_program.type = T_INT;
+		TYPEOF(mpq_program) = T_INT;
 	      }
 	    }
 
-	    if (mpq_program.type == T_PROGRAM) {
+	    if (TYPEOF(mpq_program) == T_PROGRAM) {
 #ifdef HAVE_MYSQL_FETCH_LENGTHS
 	      push_string(make_shared_binary_string(row[i], row_lengths[i]));
 #else
@@ -732,6 +750,12 @@ static void json_escape(struct string_builder *res,
   size_t i;
   // FIXME: Use string_builder_append on string segments for maximum speed
   for (i = 0; i < len; i++) {
+    if (!(i & 0xff)) {
+      /* Optimization: Make sure that there's space for at least
+       * the rest of the string unquoted.
+       */
+      string_build_mkspace(res, len-i, 0);
+    }
     switch (str[i]) {
       case 0:
  	string_builder_putchar(res, '\\');
@@ -796,8 +820,26 @@ static void json_escape(struct string_builder *res,
  *! @seealso
  *!   @[fetch_row()]
  *!
- *! @fixme
- *!   Ensure that all fields (including binary fields) are UTF-8 encoded.
+ *! @note
+ *!   This function passes on string values without any charset
+ *!   conversions. That means the result is correct JSON only if the
+ *!   result charset is UTF-8 (which includes if unicode decode mode
+ *!   is enabled - see @[set_unicode_decode_mode]).
+ *!
+ *!   For many other charsets it is possible to do charset conversion
+ *!   afterwards on the result string, since all markup is in the
+ *!   ASCII range, which is typically invariant. However, that won't
+ *!   work if binary and text results are returned at the same time.
+ *!
+ *!   Also note that the characters U+2028 (LINE SEPARATOR) and U+2029
+ *!   (PARAGRAPH SEPARATOR) are passed through without being converted
+ *!   to @tt{\uxxxx@} escapes. Those two characters can cause trouble
+ *!   with some Javascript based JSON parsers since they aren't
+ *!   allowed in Javascript string literals. It is possible to use
+ *!   @[replace] on the returned string to escape them, though.
+ *!
+ *! @seealso
+ *! @[Standards.JSON.encode]
  */
 static void f_fetch_json_result(INT32 args)
 {
@@ -842,9 +884,9 @@ next_row:
       if (row[i]) {
 	string_builder_putchar(&res, '\"');
 #ifdef HAVE_MYSQL_FETCH_LENGTHS
-	json_escape(&res, row[i], row_lengths[i]);
+	json_escape(&res, (unsigned char *) row[i], row_lengths[i]);
 #else
-	json_escape(&res, row[i], strlen([i]));
+	json_escape(&res, (unsigned char *) row[i], strlen([i]));
 #endif /* HAVE_MYSQL_FETCH_LENGTHS */
 	string_builder_putchar(&res, '\"');
       } else {
