@@ -2,7 +2,6 @@
 || This file is part of Pike. For copyright information see COPYRIGHT.
 || Pike is distributed under GPL, LGPL and MPL. See the file COPYING
 || for more information.
-|| $Id: a5eff38c9fdd251c3234b897d3da313c6d7a1e41 $
 */
 
 #include "config.h"
@@ -29,6 +28,7 @@
 #include "multiset.h"
 #include "backend.h"
 #include "operators.h"
+#include "pike_types.h"
 #include "module_support.h"
 #include "builtin_functions.h"
 
@@ -50,7 +50,7 @@ struct scanner
   SANE_Handle h;
 };
 
-static void init_sane()
+static void init_sane(void)
 {
   if( sane_init( NULL, NULL ) )
     Pike_error( "Sane init failed.\n" );
@@ -62,7 +62,7 @@ static void push_device( SANE_Device *d )
   push_text( "name" );    push_text( d->name );
   push_text( "vendor" );  push_text( d->vendor );
   push_text( "model" );   push_text( d->model );
-  push_text( "type" );    push_text( d->type );
+  ref_push_string( literal_type_string );    push_text( d->type );
   f_aggregate_mapping( 8 );
 }
 
@@ -89,7 +89,7 @@ static void push_device( SANE_Device *d )
  *!            ])
  *!        })
  */
-static void f_list_scanners( INT32 args )
+static void f_list_scanners( INT32 UNUSED(args) )
 {
   SANE_Device **devices;
   int i = 0;
@@ -127,13 +127,13 @@ static void push_option_descriptor( const SANE_Option_Descriptor *o )
     push_text( o->desc );
   else
     push_int( 0 );
-  push_text( "type" );
+  ref_push_string( literal_type_string );
   switch( o->type )
   {
    case SANE_TYPE_BOOL:   push_text( "boolean" ); break;
-   case SANE_TYPE_INT:    push_text( "int" );     break;
-   case SANE_TYPE_FIXED:  push_text( "float" );   break;
-   case SANE_TYPE_STRING: push_text( "string" );  break;
+   case SANE_TYPE_INT:    ref_push_string( literal_int_string );     break;
+   case SANE_TYPE_FIXED:  ref_push_string( literal_float_string );   break;
+   case SANE_TYPE_STRING: ref_push_string( literal_string_string );  break;
    case SANE_TYPE_BUTTON: push_text( "button" );  break;
    case SANE_TYPE_GROUP:  push_text( "group" );   break;
   }
@@ -170,14 +170,14 @@ static void push_option_descriptor( const SANE_Option_Descriptor *o )
   {
    case SANE_CONSTRAINT_NONE:  push_int( 0 ); break;
    case SANE_CONSTRAINT_RANGE:
-     push_text( "type" );  push_text( "range" );
+     ref_push_string( literal_type_string );  push_text( "range" );
      push_text( "min" );   push_int( o->constraint.range->min );
      push_text( "max" );   push_int( o->constraint.range->max );
      push_text( "quant" ); push_int( o->constraint.range->quant );
      f_aggregate_mapping( 8 );
      break;
    case SANE_CONSTRAINT_WORD_LIST:
-     push_text( "type" );
+     ref_push_string( literal_type_string );
      push_text( "list" );
      push_text( "list" );
      for( i = 0; i<o->constraint.word_list[0]; i++ )
@@ -189,7 +189,7 @@ static void push_option_descriptor( const SANE_Option_Descriptor *o )
      f_aggregate_mapping( 4 );
      break;
    case SANE_CONSTRAINT_STRING_LIST:
-     push_text( "type" );
+     ref_push_string( literal_type_string );
      push_text( "list" );
      push_text( "list" );
      for( i = 0; o->constraint.string_list[i]; i++ )
@@ -425,13 +425,14 @@ static void f_scanner_get_parameters( INT32 args )
 
 static struct program *image_program;
 
-static void get_grey_frame( SANE_Handle h, SANE_Parameters *p, char *data )
+static void get_grey_frame( SANE_Handle h, SANE_Parameters *p,
+			    SANE_Byte *data )
 {
-  char buffer[8000];
+  SANE_Byte buffer[8000];
   int nbytes = p->lines * p->bytes_per_line, amnt_read;
   while( nbytes )
   {
-    char *pp = buffer;
+    SANE_Byte *pp = buffer;
     if( sane_read( h, buffer, MINIMUM(8000,nbytes), &amnt_read ) )
       return;
     while( amnt_read-- && nbytes--)
@@ -443,13 +444,14 @@ static void get_grey_frame( SANE_Handle h, SANE_Parameters *p, char *data )
   }
 }
 
-static void get_rgb_frame( SANE_Handle h, SANE_Parameters *p, char *data )
+static void get_rgb_frame( SANE_Handle h, SANE_Parameters *p,
+			   SANE_Byte *data )
 {
-  char buffer[8000];
+  SANE_Byte buffer[8000];
   int nbytes = p->lines * p->bytes_per_line, amnt_read;
   while( nbytes )
   {
-    char *pp = buffer;
+    SANE_Byte *pp = buffer;
     if( sane_read( h, buffer, MINIMUM(8000,nbytes), &amnt_read ) )
       return;
     while( amnt_read-- && nbytes--)
@@ -457,13 +459,14 @@ static void get_rgb_frame( SANE_Handle h, SANE_Parameters *p, char *data )
   }
 }
 
-static void get_comp_frame( SANE_Handle h, SANE_Parameters *p, char *data )
+static void get_comp_frame( SANE_Handle h, SANE_Parameters *p,
+			    SANE_Byte *data )
 {
-  char buffer[8000];
+  SANE_Byte buffer[8000];
   int nbytes = p->lines * p->bytes_per_line, amnt_read;
   while( nbytes )
   {
-    char *pp = buffer;
+    SANE_Byte *pp = buffer;
     if( sane_read( h, buffer, MINIMUM(8000,nbytes), &amnt_read ) )
       return;
     while( amnt_read-- && nbytes--)
@@ -474,7 +477,7 @@ static void get_comp_frame( SANE_Handle h, SANE_Parameters *p, char *data )
   }
 }
 
-static void assert_image_program()
+static void assert_image_program(void)
 {
   if( !image_program )
   {
@@ -494,8 +497,7 @@ static void f_scanner_simple_scan( INT32 args )
   SANE_Parameters p;
   SANE_Handle h = THIS->h;
   struct object *o;
-  rgb_group *r;
-
+  SANE_Byte *r;	/* Actually an rgb_group *. */
 
   assert_image_program();
 
@@ -509,7 +511,7 @@ static void f_scanner_simple_scan( INT32 args )
   push_int( p.pixels_per_line );
   push_int( p.lines );
   o = clone_object( image_program, 2 );
-  r = ((struct image *)o->storage)->img;
+  r = (SANE_Byte *)((struct image *)o->storage)->img;
 
   THREADS_ALLOW();
   do
@@ -517,21 +519,21 @@ static void f_scanner_simple_scan( INT32 args )
     switch( p.format )
     {
      case SANE_FRAME_GRAY:
-       get_grey_frame( h, &p, (char *)r );
+       get_grey_frame( h, &p, r );
        p.last_frame = 1;
        break;
      case SANE_FRAME_RGB:
-       get_rgb_frame(  h, &p, (char *)r );
+       get_rgb_frame( h, &p, r );
        p.last_frame = 1;
        break;
      case SANE_FRAME_RED:
-       get_comp_frame( h, &p, ((char *)r) );
+       get_comp_frame( h, &p, r );
        break;
      case SANE_FRAME_GREEN:
-       get_comp_frame( h, &p, ((char *)r)+1 );
+       get_comp_frame( h, &p, r + 1 );
        break;
      case SANE_FRAME_BLUE:
-       get_comp_frame( h, &p, ((char *)r)+2 );
+       get_comp_frame( h, &p, r + 2 );
        break;
     }
   }
@@ -549,7 +551,7 @@ static void f_scanner_row_scan( INT32 args )
   SANE_Handle h = THIS->h;
   struct svalue *s;
   struct object *o;
-  rgb_group *r, or;
+  SANE_Byte *r; /* Actually an rgb_group *. */
   int i, nr;
 
   if( sane_start( THIS->h ) )               Pike_error("Start failed\n");
@@ -571,7 +573,7 @@ static void f_scanner_row_scan( INT32 args )
   push_int( p.pixels_per_line );
   push_int( 1 );
   o = clone_object( image_program, 2 );
-  r = ((struct image *)o->storage)->img;
+  r = (SANE_Byte *)((struct image *)o->storage)->img;
 
   nr = p.lines;
   p.lines=1;
@@ -582,10 +584,10 @@ static void f_scanner_row_scan( INT32 args )
     switch( p.format )
     {
      case SANE_FRAME_GRAY:
-       get_grey_frame( h, &p, (char *)r );
+       get_grey_frame( h, &p, r );
        break;
      case SANE_FRAME_RGB:
-       get_rgb_frame(  h, &p, (char *)r );
+       get_rgb_frame( h, &p, r );
        break;
      case SANE_FRAME_RED:
      case SANE_FRAME_GREEN:
@@ -612,7 +614,7 @@ struct row_scan_struct
   struct object *o;
   struct object *t;
   int current_row;
-  char *buffer;
+  SANE_Byte *buffer;
   int bufferpos, nonblocking;
   struct svalue callback;
 };
@@ -649,7 +651,7 @@ static void nonblocking_row_scan_callback( int fd, void *_c )
            }
            break;
          case SANE_FRAME_RGB:
-           MEMCPY( (char *)c->r, c->buffer, c->p.bytes_per_line );
+           memcpy( c->r, c->buffer, c->p.bytes_per_line );
            break;
          default:break;
         }
@@ -687,7 +689,7 @@ static void nonblocking_row_scan_callback( int fd, void *_c )
 
 /*! @decl void nonblocking_row_scan(function(Image.Image,int,Scanner,int:void) callback)
  */
-static void f_scanner_nonblocking_row_scan( INT32 args )
+static void f_scanner_nonblocking_row_scan( INT32 UNUSED(args) )
 {
   SANE_Parameters p;
   SANE_Handle h = THIS->h;
@@ -744,7 +746,7 @@ static void f_scanner_nonblocking_row_scan( INT32 args )
 
 /*! @decl void cancel_scan()
  */
-static void f_scanner_cancel_scan( INT32 args )
+static void f_scanner_cancel_scan( INT32 UNUSED(args) )
 {
   sane_cancel( THIS->h );
 }
@@ -762,12 +764,12 @@ static void f_scanner_cancel_scan( INT32 args )
 /*! @endmodule
  */
 
-static void init_scanner_struct( struct object *p )
+static void init_scanner_struct( struct object *UNUSED(p) )
 {
   THIS->h = 0;
 }
 
-static void exit_scanner_struct( struct object *p )
+static void exit_scanner_struct( struct object *UNUSED(p) )
 {
   if( THIS->h )
     sane_close( THIS->h );
