@@ -2,7 +2,6 @@
 || This file is part of Pike. For copyright information see COPYRIGHT.
 || Pike is distributed under GPL, LGPL and MPL. See the file COPYING
 || for more information.
-|| $Id: 84bbd9cbbb22b5121cd76c8508487316c067d39f $
 */
 
 #include "config.h"
@@ -246,7 +245,7 @@ static void image_ttf_make(INT32 args)
    TT_Error res;
    TT_Face face;
 
-   if (sp[-args].type!=T_STRING)
+   if (TYPEOF(sp[-args]) != T_STRING)
       Pike_error("Image.TTF(): illegal argument 1\n");
 
    res=TT_Open_Collection(engine, sp[-args].u.string->str, col, &face);
@@ -268,8 +267,8 @@ static void image_ttf_make(INT32 args)
 */
 
 #define THISOBJ (Pike_fp->current_object)
-#define THISf ((struct image_ttf_face_struct*)get_storage(THISOBJ,image_ttf_face_program))
-#define THISi ((struct image_ttf_faceinstance_struct*)get_storage(THISOBJ,image_ttf_faceinstance_program))
+#define THISf ((struct image_ttf_face_struct *)get_storage(THISOBJ,image_ttf_face_program))
+#define THISi ((struct image_ttf_faceinstance_struct *)get_storage(THISOBJ,image_ttf_faceinstance_program))
 
 static void image_ttf_face_exit(struct object *o)
 {
@@ -556,7 +555,7 @@ static void image_ttf_face_names(INT32 args)
 
    image_ttf_face__names(args);
 
-   if (sp[-1].type!=T_ARRAY)
+   if (TYPEOF(sp[-1]) != T_ARRAY)
       Pike_error("Image.TTF.Face->names(): internal error, weird _names()\n");
 
    a=sp[-1].u.array;
@@ -682,9 +681,8 @@ static void image_ttf_faceinstance_create(INT32 args)
    if (!args)
       Pike_error("Image.TTF.FaceInstance(): too few arguments\n");
 
-   if (sp[-args].type!=T_OBJECT ||
-       !(face_s=(struct image_ttf_face_struct*)
-	 get_storage(sp[-args].u.object,image_ttf_face_program)))
+   if (TYPEOF(sp[-args]) != T_OBJECT ||
+       !(face_s=get_storage(sp[-args].u.object,image_ttf_face_program)))
       Pike_error("Image.TTF.FaceInstance(): illegal argument 1\n");
 
    if ((res=TT_New_Instance(face_s->face,&(face_i->instance))))
@@ -705,16 +703,15 @@ static void image_ttf_faceinstance_set_height(INT32 args)
    if (!args)
       Pike_error("Image.TTF.FaceInstance->set_height(): missing arguments\n");
 
-   if (sp[-args].type==T_INT)
+   if (TYPEOF(sp[-args]) == T_INT)
       h = sp[-args].u.integer*64;
-   else if (sp[-args].type==T_FLOAT)
+   else if (TYPEOF(sp[-args]) == T_FLOAT)
       h = DOUBLE_TO_INT(sp[-args].u.float_number*64);
    else
       Pike_error("Image.TTF.FaceInstance->set_height(): illegal argument 1\n");
    if (h<1) h=1;
 
-   if (!(face_s=(struct image_ttf_face_struct*)
-	 get_storage(THISi->faceobj,image_ttf_face_program)))
+   if (!(face_s=get_storage(THISi->faceobj,image_ttf_face_program)))
       Pike_error("Image.TTF.FaceInstance->write(): lost Face\n");
 
    ttf_instance_setc(face_s,face_i,h,"Image.TTF.FaceInstance->set_height()");
@@ -731,7 +728,7 @@ static void ttf_translate_8bit(TT_CharMap charMap,
 {
    int i;
 
-   dest[0]=(int*)xalloc(len*sizeof(int));
+   dest[0]=xalloc(len*sizeof(int));
 
    THREADS_ALLOW();
    for (i=0; i<len; i++)
@@ -748,7 +745,7 @@ static void ttf_translate_16bit(TT_CharMap charMap,
 {
    int i;
 
-   dest[0]=(int*)xalloc(len*sizeof(int));
+   dest[0]=xalloc(len*sizeof(int));
 
    THREADS_ALLOW();
    for (i=0; i<len; i++)
@@ -836,18 +833,17 @@ static void image_ttf_faceinstance_ponder(INT32 args)
 
    int xmin=1000,xmax=-1000,pos=0;
 
-   if (!(face_s=(struct image_ttf_face_struct*)
-	 get_storage(THISi->faceobj,image_ttf_face_program)))
+   if (!(face_s=get_storage(THISi->faceobj,image_ttf_face_program)))
       Pike_error("Image.TTF.FaceInstance->ponder(): lost Face\n");
 
-   if (args && sp[-1].type==T_INT)
+   if (args && TYPEOF(sp[-1]) == T_INT)
    {
       base=sp[-1].u.integer;
       args--;
       pop_stack();
    }
 
-   if (sp[-args].type!=T_STRING)
+   if (TYPEOF(sp[-args]) != T_STRING)
       Pike_error("Image.TTF.FaceInstance->ponder(): illegal argument 1\n");
 
    switch( sp[-args].u.string->size_shift )
@@ -990,8 +986,7 @@ static void image_ttf_faceinstance_write(INT32 args)
    unsigned char* pixmap;
    int maxcharwidth = 0;
 
-   if (!(face_s=(struct image_ttf_face_struct*)
-	 get_storage(THISi->faceobj,image_ttf_face_program)))
+   if (!(face_s=get_storage(THISi->faceobj,image_ttf_face_program)))
       Pike_error("Image.TTF.FaceInstance->write(): lost Face\n");
 
    if(!TT_Get_Kerning_Directory( face_s->face, &kerning ))
@@ -1005,7 +1000,7 @@ static void image_ttf_faceinstance_write(INT32 args)
 /*      fprintf(stderr, "offset=%d\n", (int)metrics.x_scale); */
    }
 
-   if (args && sp[-1].type==T_INT)
+   if (args && TYPEOF(sp[-1]) == T_INT)
    {
       base=sp[-1].u.integer;
       args--;
@@ -1031,7 +1026,7 @@ static void image_ttf_faceinstance_write(INT32 args)
      char *errs=NULL;
      TT_Glyph_Metrics metrics;
 
-      if (sp[a-args].type!=T_STRING)
+      if (TYPEOF(sp[a-args]) != T_STRING)
 	 Pike_error("Image.TTF.FaceInstance->write(): illegal argument %d\n",a+1);
 
       switch(sp[a-args].u.string->size_shift)
@@ -1137,7 +1132,7 @@ static void image_ttf_faceinstance_write(INT32 args)
       push_int(width);
       push_int(height);
       o=clone_object(image_program,2);
-      img=(struct image*)get_storage(o,image_program);
+      img=get_storage(o,image_program);
       d=img->img;
 
       for (a=0; a<args; a++)
@@ -1164,7 +1159,7 @@ static void image_ttf_faceinstance_write(INT32 args)
 	    if ((res=TT_Get_Glyph_Metrics(glyph,&metrics)))
 	       { errs="TT_Get_Glyph_Metrics: "; break; }
 
-	    MEMSET(pixmap,0,rastermap.size);
+	    memset(pixmap,0,rastermap.size);
 
 	    if ((res=TT_Get_Glyph_Pixmap(glyph,
 					 &rastermap,
@@ -1282,7 +1277,7 @@ PIKE_MODULE_INIT
 #ifdef DYNAMIC_MODULE
    push_text("Image.Image");
    SAFE_APPLY_MASTER("resolv",1);
-   if (sp[-1].type==T_PROGRAM)
+   if (TYPEOF(sp[-1]) == T_PROGRAM)
       image_program=program_from_svalue(sp-1);
    pop_stack();
 #endif /* DYNAMIC_MODULE */
