@@ -2,7 +2,6 @@
 || This file is part of Pike. For copyright information see COPYRIGHT.
 || Pike is distributed under GPL, LGPL and MPL. See the file COPYING
 || for more information.
-|| $Id: 5b68fee09852a9818b702dd7c6becb19cd2a6cc5 $
 */
 
 #include "config.h"
@@ -25,6 +24,7 @@
 #include "module_support.h"
 #include "operators.h"
 #include "program.h"
+#include "pike_types.h"
 
 #include "modules/Image/image.h"
 
@@ -60,7 +60,7 @@ static void do_resize( gint *width, gint *height, gpointer user_data )
   /* Exact size specified */
   
   if( (opt = simple_mapping_string_lookup( opts, "xsize" ))
-      && opt->type == PIKE_T_INT)
+      && TYPEOF(*opt) == PIKE_T_INT)
   {
     xsize = opt->u.integer;
     *height = (*height * xsize) / *width;
@@ -68,7 +68,7 @@ static void do_resize( gint *width, gint *height, gpointer user_data )
   }
 
   if( (opt = simple_mapping_string_lookup( opts, "ysize" ))
-      && opt->type == PIKE_T_INT)
+      && TYPEOF(*opt) == PIKE_T_INT)
   {
     if( xsize )
       *height = opt->u.integer;
@@ -86,7 +86,7 @@ static void do_resize( gint *width, gint *height, gpointer user_data )
 
   /* Scale specified */
   if( (opt = simple_mapping_string_lookup( opts, "scale" ))
-      && opt->type == PIKE_T_FLOAT )
+      && TYPEOF(*opt) == PIKE_T_FLOAT )
   {
     *width *= opt->u.float_number;
     *height *= opt->u.float_number;
@@ -103,44 +103,51 @@ static void low__decode( INT32 args, int header_only )
   struct pike_string *data;
   struct mapping *opts = 0;
   struct svalue *debugsp = Pike_sp;
+
   if( args > 2 )
-    Pike_error("Too many arguments\n");
+    Pike_error("Too many arguments.\n");
   
   if( args == 2 )
   {
-    if( Pike_sp[-1].type != PIKE_T_MAPPING )
-      Pike_error("Illegal argument 2, expected mapping\n");
+    if( TYPEOF(Pike_sp[-1]) != PIKE_T_MAPPING )
+      Pike_error("Illegal argument 2, expected mapping.\n");
     opts = Pike_sp[-1].u.mapping;
     Pike_sp--;
     args--;
   }
 
-  if( Pike_sp[-1].type != PIKE_T_STRING )
-    Pike_error("Illegal argument 1, expected string\n");
+  if( TYPEOF(Pike_sp[-args]) != PIKE_T_STRING ) {
+    _do_free_mapping(opts);
+    Pike_error("Illegal argument 1, expected string.\n");
+  }
 
   f_string_to_utf8( 1 );
   data = Pike_sp[-1].u.string;
   handle = rsvg_handle_new( );
 
-  if( !handle )
-    Pike_error("rsvg_handle_new() failed\n");
+  if( !handle ) {
+    _do_free_mapping(opts);
 
-  rsvg_handle_set_size_callback( handle, do_resize,
-				 (void *)opts, _do_free_mapping );
+    Pike_error("rsvg_handle_new() failed.\n");
+  }
+
+  rsvg_handle_set_size_callback( handle, do_resize, (void *)opts, NULL );
 
   rsvg_handle_write( handle, (void *)data->str, data->len, &err );
 
+  _do_free_mapping(opts);
+
   if( err )
   {
     rsvg_handle_free( handle );
-    Pike_error("Failed to decode SVG\n");
+    Pike_error("Failed to decode SVG.\n");
   }
   rsvg_handle_close( handle, &err );
 
   if( err )
   {
     rsvg_handle_free( handle );
-    Pike_error("Failed to decode SVG\n");
+    Pike_error("Failed to decode SVG.\n");
   }
 
   res = rsvg_handle_get_pixbuf( handle );
@@ -149,7 +156,7 @@ static void low__decode( INT32 args, int header_only )
   if( !res )
   {
     rsvg_handle_free( handle );
-    Pike_error("Failed to decode SVG\n");
+    Pike_error("Failed to decode SVG.\n");
   }
   
   {
@@ -164,7 +171,7 @@ static void low__decode( INT32 args, int header_only )
     
     push_text( "xsize" ); push_int( xs );
     push_text( "ysize" ); push_int( ys );
-    push_text( "type" );  push_text( "image/svg");
+    ref_push_string( literal_type_string );  push_text( "image/svg");
     if( !header_only )
     {
       push_text( "Image.Image" );
@@ -359,7 +366,11 @@ static void f_decode( INT32 args )
 PIKE_MODULE_INIT
 {
 #ifdef HAVE_SVG
+#ifdef HAVE_SVG_2_36_OR_NEWER
   g_type_init(); /* Initialize the glib type system. */
+#else
+  rsvg_init(); /* Initialize librsvg */
+#endif
 
   add_function( "decode", f_decode,
 		"function(string,mapping|void:object)", 0 );
